@@ -12,8 +12,8 @@
 #define STATEDUMP_H
 
 #include <stdarg.h>
-#include "inode.h"
-#include "strfd.h"
+#include "glusterfs/inode.h"
+#include "glusterfs/strfd.h"
 
 #define GF_DUMP_MAX_BUF_LEN 4096
 
@@ -58,18 +58,8 @@ _gf_proc_dump_build_key(char *key, const char *prefix, const char *fmt, ...)
         _gf_proc_dump_build_key(key, key_prefix, ##fmt);                       \
     }
 
-#define GF_PROC_DUMP_SET_OPTION(opt, val) opt = val
-
-#define GF_CHECK_DUMP_OPTION_ENABLED(option_dump, var, label)                  \
-    do {                                                                       \
-        if (option_dump == _gf_true) {                                         \
-            var = _gf_false;                                                   \
-            goto label;                                                        \
-        }                                                                      \
-    } while (0);
-
 void
-gf_proc_dump_init();
+gf_proc_dump_init(void);
 
 void
 gf_proc_dump_fini(void);
@@ -127,4 +117,6 @@ gf_proc_dump_xlator_meminfo(xlator_t *this, strfd_t *strfd);
 void
 gf_proc_dump_xlator_profile(xlator_t *this, strfd_t *strfd);
 
+void
+gf_latency_statedump_and_reset(char *key, gf_latency_t *lat);
 #endif /* STATEDUMP_H */
